@@ -155,36 +155,36 @@ EarlyConservationTest <- function(ExpressionSet,
                 if(runs < 1)
                         stop("You need at least one run...")
                 
-                # plot histogram of scores
-                normDensity <- function(x){
-                        
-                        return(dnorm(x,mu,sigma))
-                        
-                }
-                
                 if(lillie.test)
-                        par(mfrow = c(2,2))
+                        graphics::par(mfrow = c(2,2))
                 if(!lillie.test)
-                        par(mfrow = c(1,3))
+                        graphics::par(mfrow = c(1,3))
                 
                 fitdistrplus::descdist(score_vector, boot = permutations)
                 
-                curve( expr = normDensity,
+                # plot histogram of scores
+                normDensity <- function(x){
+                        
+                        return(stats::dnorm(x,mu,sigma))
+                        
+                }
+                
+                graphics::curve( expr = normDensity,
                        xlim = c(min(score_vector),max(score_vector,real_ecv)),
                        col  = "steelblue",
                        lwd  = 5,
                        xlab = "Scores",
                        ylab = "Frequency" )
                 
-                hist( x      = score_vector,
+                graphics::hist( x      = score_vector,
                       prob   = TRUE,
                       add    = TRUE, 
                       breaks = permutations / (0.01 * permutations) )
                 
-                rug(score_vector)
+                graphics::rug(score_vector)
                 
                 # plot a red line at the position where we can find the real ec value
-                abline(v = real_ecv, lwd = 5, col = "darkred")
+                graphics::abline(v = real_ecv, lwd = 5, col = "darkred")
                 
                 #legend("topleft", legend = "A", bty = "n")
                 
@@ -268,39 +268,36 @@ EarlyConservationTest <- function(ExpressionSet,
                         }
                 }
                 
-                plot( x    = p.vals_vec,
-                      type = "l" , 
-                      lwd  = 6, 
-                      ylim = c(0,1), 
-                      col  = "darkblue", 
-                      xlab = "Runs", 
-                      ylab = "p-value" )
+                graphics::plot( x    = p.vals_vec,
+                                type = "l" , 
+                                lwd  = 6, 
+                                ylim = c(0,1), 
+                                col  = "darkblue", 
+                                xlab = "Runs", 
+                                ylab = "p-value" )
+
+                graphics::abline(h = 0.05, lty = 2, lwd = 3)
 
-                abline(h = 0.05, lty = 2, lwd = 3)
-                #legend("topleft", legend = "B", bty = "n")
-                
                 if(lillie.test){
                         tbl <- table(factor(lillie_vec, levels = c("FALSE","TRUE")))
                         
-                        barplot( height    = tbl/sum(tbl) , 
-                                 beside    = TRUE, 
-                                 names.arg = c("FALSE", "TRUE"), 
-                                 ylab      = "relative frequency", 
-                                 main      = paste0("runs = ",runs) )
-                        
-                        #legend("topleft", legend = "C", bty = "n")
+                        graphics::barplot( height    = tbl/sum(tbl) , 
+                                           beside    = TRUE, 
+                                           names.arg = c("FALSE", "TRUE"), 
+                                           ylab      = "relative frequency", 
+                                           main      = paste0("runs = ",runs) )
                 }
         }
         
         
         #if(real_ecv >= 0)
-        pval <- pnorm(real_ecv,mean = mu,sd = sigma,lower.tail = FALSE)
+        pval <- stats::pnorm(real_ecv,mean = mu,sd = sigma,lower.tail = FALSE)
         
         #if(real_ecv < 0)
         #pval <- pnorm(real_ecv,mean=mu,sd=sigma,lower.tail=TRUE)
         ### computing the standard deviation of the sampled TAI values for each stage separately
         sd_vals <- vector(mode = "numeric",length = nCols-2)
-        sd_vals <- apply(resMatrix,2,sd)
+        sd_vals <- apply(resMatrix,2,stats::sd)
         
         if(lillie.test){
                 # perform Lilliefors K-S-Test
